Learn R Programming

Mmcsd (version 1.0.0)

sigmaThetaExpr_viewer: covariance structure viewer to preview sigmaThetaExpr to be used in 'cov_mmcsd'.

Description

Knowing the difficulty of visualizing the covariance structure, especially when the user chooses to determine his own structure. This function was developed,that allows the user to view the provided structure even before it is evaluated, that is, through mathematics symbolic.

Usage

sigmaThetaExpr_viewer(sigmaThetaExpr, numWaves = NULL)

Value

Return NULL and print in terminal the sigmaThetaExpr.

Arguments

sigmaThetaExpr

A character with the covariance structure type or a list of expressions

numWaves

An integer with the size of the square matrix to be printed.

Examples

Run this code
sigmaThetaExpr_viewer("UCM", 5)

Run the code above in your browser using DataLab